@@ -19,8 +19,9 @@
 #include "Rcpp.h"
 #include <gdtools.h>
 #include <string.h>
+#include <iostream>
 #include "R_ext/GraphicsEngine.h"
-#include "rotate.h"
+#include "utils.h"
 #include "fonts.h"
 #include "xfrm.h"
 #include "nv_pr.h"
@@ -29,12 +30,29 @@
 #include "ppr.h"
 #include "line_style.h"
 #include "main_tree.h"
-#include "body_pr.h"
-#include "a_path.h"
 #include "a_prstgeom.h"
-#include "empty_body_text.h"
 #include "clipper.h"
 
+std::string xlsx_empty_body_text(){
+  std::stringstream os;
+  os << "<xdr:txBody>";
+  os << "<a:bodyPr/><a:lstStyle/><a:p/>";
+  os << "</xdr:txBody>";
+  return os.str();
+}
+
+std::string xlsx_body_pr()
+{
+  std::stringstream os;
+
+  os << "<a:bodyPr ";
+  os << "lIns=\"0\" rIns=\"0\" tIns=\"0\" bIns=\"0\" ";
+  os << "anchorCtr=\"1\" anchor=\"ctr\" wrap=\"none\"/>";
+  os << "<a:lstStyle/>";
+
+  return os.str();
+}
+
 // SVG device metadata
 class XLSX_dev {
 public:
@@ -132,7 +150,7 @@ void write_text_body_xlsx(pDevDesc dd, R_GE_gcontext *gc, const char* text, doub
   rpr rpr_(fontsize, is_italic(gc->fontface), is_bold(gc->fontface), gc->col, fontname_);
 
   fputs("<xdr:txBody>", xlsx_obj->file );
-  fprintf(xlsx_obj->file, "%s", body_pr::a_tag().c_str() );
+  fprintf(xlsx_obj->file, "%s", xlsx_body_pr().c_str() );
   fputs("<a:p>", xlsx_obj->file );
   fprintf(xlsx_obj->file, "%s", a_ppr_.a_tag().c_str() );
   fputs("<a:r>", xlsx_obj->file );
@@ -235,12 +253,12 @@ void xlsx_do_polyline(NumericVector x, NumericVector y, const pGEcontext gc,
   fprintf(xlsx_obj->file, "%s", xfrm_.xml().c_str());
   fputs( "<a:custGeom><a:avLst/>", xlsx_obj->file );
   fputs( "<a:pathLst>", xlsx_obj->file );
-  fprintf(xlsx_obj->file, "%s", a_path::a_tag(x, y, 0 ).c_str());
+  fprintf(xlsx_obj->file, "%s", a_path(x, y, 0 ).c_str());
   fputs( "</a:pathLst>", xlsx_obj->file );
   fputs( "</a:custGeom>", xlsx_obj->file );
   fprintf(xlsx_obj->file, "%s", line_style_.a_tag().c_str());
   fputs("</xdr:spPr>", xlsx_obj->file);
-  fprintf(xlsx_obj->file, "%s",empty_body_text::x_tag().c_str());
+  fprintf(xlsx_obj->file, "%s",xlsx_empty_body_text().c_str());
   fputs("</xdr:sp>", xlsx_obj->file);
 }
 
@@ -321,14 +339,14 @@ static void xlsx_polygon(int n, double *x, double *y, const pGEcontext gc,
       fprintf(xlsx_obj->file, "%s", xfrm_.xml().c_str());
       fputs("<a:custGeom><a:avLst/>", xlsx_obj->file );
         fputs( "<a:pathLst>", xlsx_obj->file );
-          fprintf(xlsx_obj->file, "%s", a_path::a_tag(x__, y__, 1 ).c_str());
+          fprintf(xlsx_obj->file, "%s", a_path(x__, y__, 1 ).c_str());
         fputs( "</a:pathLst>", xlsx_obj->file );
       fputs("</a:custGeom>", xlsx_obj->file );
       if( fill_.is_visible() > 0 )
         fprintf(xlsx_obj->file, "%s", fill_.solid_fill().c_str());
       fprintf(xlsx_obj->file, "%s", line_style_.a_tag().c_str());
     fputs("</xdr:spPr>", xlsx_obj->file);
-    fprintf(xlsx_obj->file, "%s",empty_body_text::x_tag().c_str());
+    fprintf(xlsx_obj->file, "%s",xlsx_empty_body_text().c_str());
   fputs("</xdr:sp>", xlsx_obj->file);
 }
 
@@ -368,7 +386,7 @@ static void xlsx_rect(double x0, double y0, double x1, double y1,
         fprintf(xlsx_obj->file, "%s", fill_.solid_fill().c_str());
       fprintf(xlsx_obj->file, "%s", line_style_.a_tag().c_str());
     fputs("</xdr:spPr>", xlsx_obj->file);
-    fprintf(xlsx_obj->file, "%s",empty_body_text::x_tag().c_str());
+    fprintf(xlsx_obj->file, "%s",xlsx_empty_body_text().c_str());
   fputs("</xdr:sp>", xlsx_obj->file);
 }
 
@@ -389,7 +407,7 @@ static void xlsx_circle(double x, double y, double r, const pGEcontext gc,
         fprintf(xlsx_obj->file, "%s", fill_.solid_fill().c_str());
       fprintf(xlsx_obj->file, "%s", line_style_.a_tag().c_str());
     fputs("</xdr:spPr>", xlsx_obj->file);
-    fprintf(xlsx_obj->file, "%s",empty_body_text::x_tag().c_str());
+    fprintf(xlsx_obj->file, "%s",xlsx_empty_body_text().c_str());
 
   fputs("</xdr:sp>", xlsx_obj->file);
 }
